@@ -1661,3 +1661,32 @@ class DATASETS:
     NUM_METRICS_PROPERTY = "num_metrics"
     CONDITIONS_PROPERTY = "conditions"
     METRICS_PROPERTY = "metrics"
+
+
+class T_SPSA:
+    """
+    String constants related to T-SPSA
+    """
+    a = "a"
+    c = "c"
+    LAMBDA = "lambda"
+    A = "A"
+    EPSILON = "epsilon"
+    N = "N"
+    L = "L"
+    THETA1 = "theta1"
+    THETAS = "thetas"
+    THRESHOLDS = "thresholds"
+    GRADIENT_BATCH_SIZE = "gradient_batch_size"
+    STOP_DISTRIBUTION_ATTACKER = "stop_distribution_attacker"
+    STOP_DISTRIBUTION_DEFENDER = "stop_distribution_defender"
+
+
+class NEURAL_NETWORKS:
+    """
+    Constants related to neural networks
+    """
+    NUM_NEURONS_PER_HIDDEN_LAYER = "num_neurons_per_hidden_layer"
+    NUM_HIDDEN_LAYERS = "num_hidden_layers"
+    ACTIVATION_FUNCTION = "activation_function"
+    DEVICE = "device"
